summaryrefslogtreecommitdiffstats
path: root/bftw.h
diff options
context:
space:
mode:
Diffstat (limited to 'bftw.h')
-rw-r--r--bftw.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/bftw.h b/bftw.h
index 77148f1..ebdd5d3 100644
--- a/bftw.h
+++ b/bftw.h
@@ -17,8 +17,8 @@
#ifndef BFS_BFTW_H
#define BFS_BFTW_H
+#include "stat.h"
#include <stddef.h>
-#include <sys/stat.h>
/**
* Possible file types.
@@ -81,8 +81,8 @@ struct BFTW {
/** The errno that occurred, if typeflag == BFTW_ERROR. */
int error;
- /** A stat() buffer; may be NULL if no stat() call was needed. */
- const struct stat *statbuf;
+ /** A bfs_stat() buffer; may be NULL if no stat() call was needed. */
+ const struct bfs_stat *statbuf;
/** A parent file descriptor for the *at() family of calls. */
int at_fd;